import qs from 'qs'

// 请求基准地址
const baseUrl = import.meta.env.VITE_BASE_URL



// 拦截器配置
const httpInterceptor = {
  // 拦截前触发
  invoke(options) {
    // 接口请求支持通过 query 参数配置 queryString
    if (options.query) {
      const queryStr = qs.stringify(options.query)
      if (options.url.includes('?')) {
        options.url += `&${queryStr}`
      } else {
        options.url += `?${queryStr}`
      }
    }
    if (options.params) {
      options.data = options.params || {}
    }
    options.url = baseUrl + options.url
    options.method = options.method || 'GET'
    // 1. 请求超时
    options.timeout = 10000 // 10s
    // 2. 添加 token 请求头标识
    const token = uni.getStorageSync('token');
    if (token && !options.noToken) {
      options.header.Authorization = `Bearer ${token}`
    }
  }
}

export const requestInterceptor = {
  install() {
    // 拦截 request 请求
    uni.addInterceptor('request', httpInterceptor)
  },
}
